==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/circles/l10n/cs.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Okruhy",
    "Circles' files" : "Soubory okruhu",
    "Select circles to filter by" : "Vyberte okruhy, které chcete filtrovat",
    "No circles found" : "Nenalezeny žádné okruhy",
    "Please select circles to filter by" : "Vyberte okruhy, které chcete filtrovat",
    "No files found for the selected circles" : "Pro vybrané okruhy nebyly nalezeny žádné soubory",
    "You created the circle {circle}" : "Vytvořili jste okruh {circle}",
    "{author} created the circle {circle}" : "{author} vytvořil(a) okruh {circle}",
    "You deleted {circle}" : "Smazali jste okruh {circle}",
    "{author} deleted {circle}" : "{author} smazal(a) {circle}",
    "You linked {group} to {circle}" : "Připojili jste {group} k {circle}",
    "{group} has been linked to {circle} by {author}" : "skupina {group} byla připojena k {circle} uživatelem {author}",
    "You unlinked {group} from {circle}" : "Odpojili jste {group} od {circle}",
    "{group} has been unlinked from {circle} by {author}" : "skupina {group} byla odpojena od {circle} uživatelem {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Změnil(a) jste úroveň připojené skupiny {group} v {circle} na %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} změnil(a) úroveň připojené skupiny {group} v {circle} na %1$s",
    "You sent a request to link {circle} with {remote}" : "Poslali jste požadavek na odkaz {circle} s {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} poslal(a) požadavek na propojení {circle} s {remote}",
    "{remote} requested a link with {circle}" : "{remote} požádal(a) o spojení s {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Požadavek na propojení {circle} s {remote} byl zamítnut",
    "The request to link {remote} with {circle} has been canceled remotely" : "Požadavek na propojení {remote} s {circle} byl zrušen",
    "The request to link {circle} with {remote} has been accepted" : "Požadavek na propojení {circle} s {remote} byl přijat",
    "You dismissed the request to link {remote} with {circle}" : "Odmítli jste požadavek na propojení {remote} s {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} skryl(a) požadavek na propojení {remote} s {circle}",
    "You canceled the request to link {circle} with {remote}" : "Odvolali jste svůj požadavek na propojení {circle} s {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} odvolal(a) svůj požadavek na propojení {circle} s {remote}",
    "You accepted the request to link {remote} with {circle}" : "Přijali jste požadavek na propojení {remote} s {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} přijal(a) požadavek na propojení {remote} s {circle}",
    "A link between {circle} and {remote} is now up and running" : "Propojení mezi {circle} a {remote} je nyní zapnuté a spuštěné",
    "The link between {circle} and {remote} has been shutdown remotely" : "Propojení mezi {circle} a {remote} bylo druhou stranou vypnuto",
    "You closed the link between {circle} and {remote}" : "Zavřeli jste propojení mezi {circle} a {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} uzavřel(a) spojení mezi {circle} a {remote}",
    "You joined {circle}" : "Připojili jste se k {circle}",
    "{member} joined {circle}" : "{member} se připojil(a) k {circle}",
    "You accepted the invitation to join {circle}" : "Přijali jste pozvánku k připojení  se do {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} přijal(a) pozvánku připojit se k  {circle}",
    "You added {member} as member to {circle}" : "Přidali jste {member} jako člena {circle}",
    "You have been added as member to {circle} by {author}" : " {author} vás přidal(a) jako člena {circle} ",
    "{member} has been added as member to {circle} by {author}" : "{author} přidal(a) {member} jako člena do {circle}",
    "You added {external} to {circle}" : "Přidali jste {external} do {circle}",
    "{external} has been added to {circle} by {author}" : "{author} přidal(a) {external} do {circle} ",
    "You accepted {member}'s request to join {circle}" : "Přijali jste požadavek od {member} na připojení se do {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Váš požadavek na přidání se k {circle} byl {author} přijat",
    "{member}'s request to join {circle} has been accepted by {author}" : "Požadavek {member} na přidání do {circle} byl {author} přijat",
    "You left {circle}" : "Odešli jste z {circle}",
    "{member} left {circle}" : "{member} opustil(a) {circle}",
    "You declined the invitation to join {circle}" : "Odmítli jste pozvání k přidání se k {circle}",
    "{member} declined an invitation to join {circle}" : "{member} odmítl pozvání k přidání se {circle}",
    "You cancelled your request to join {circle}" : "Vzali jste zpět svou žádost na připojení se k {circle}",
    "{member} cancelled his request to join {circle}" : "{member} zrušil svůj požadavek na přidání se k {circle}",
    "You removed {member} from {circle}" : "Odebrali jste {member} z {circle}",
    "You have been removed from {circle} by {author}" : "{author} vás odebral(a) z {circle}  ",
    "{member} has been removed from {circle} by {author}" : "{author} odebral(a) {member} z {circle}",
    "You removed {external} from {circle}" : "Odebrali jste {external} z {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odebral(a) {external} z {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Zrušili jste pozvánku pro {member} připojení se k {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} zrušil(a) pozvání k připojení se do {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} zrušil(a) pozvánku pro {member} pro připojení se k {circle}",
    "You dismissed {member}'s request to join {circle}" : "Schovali jste požadavek od {member} ohledně připojení se k {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} zahodil váš požadavek na přidání se do {circle} ",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} zahodil požadavek od {member} na zapojení se do {circle} ",
    "You invited {member} to join {circle}" : "Pozvali jste {member} aby se připojil(a) k {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vás pozval(a) do {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pozval(a) {member} do {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Změnili jste úroveň {member} v {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} změnil(a) vaši úroveň v {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} změnil(a) úroveň {member} v {circle} na %1$s",
    "You sent a request to join {circle}" : "Poslali jste požadavek na připojení k {circle}",
    "{member} sent a request to join {circle}" : "{member} poslal(a) požadavek na připojení se k {circle}",
    "You are the new owner of {circle}" : "Stali jste se novým vlastníkem {circle}",
    "{member} is the new owner of {circle}" : "{member} je novým vlastníkem {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Při událostech odehrávajících se v<strong>okruhu</strong>, kterého jste členy",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Důležité události v <strong>Okruhu</strong>, který moderujete",
    "On global events happening in any <strong>Circle</strong>" : "Při globálních událostech odehrávajících se v jakémkoli <strong>okruhu</strong>",
    "Single" : "Jediné",
    "Personal" : "Osobní",
    "System" : "Systém",
    "Visible" : "Viditelný",
    "Open" : "Otevřít",
    "Invite" : "Pozvat",
    "Join Request" : "Žádost o přidání se",
    "Friends" : "Přátelé",
    "Password Protected" : "Chráněno heslem",
    "No Owner" : "Bez vlastníka",
    "Hidden" : "Skrytý",
    "Backend" : "Podpůrná vrstva",
    "Local" : "Místní",
    "Root" : "Kořen",
    "Circle Invite" : "Pozvání do okruhu",
    "Federated" : "Propojené",
    "Mount point" : "Přípojný bod",
    "Nextcloud Account" : "Nextcloud účet",
    "Nextcloud Group" : "Skupina v Nextcloud",
    "Email Address" : "E-mailová adresa",
    "Contact" : "Kontakt",
    "Circle" : "Okruh",
    "Nextcloud App" : "Nextcloud aplikace",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Správce",
    "Owner" : "Vlastník",
    "%s shared »%s« with you." : "%s vám nasdílel(a) „%s“.",
    "%s shared »%s« with \"%s\"." : "%s nasdílel(a) „%s“ uživateli „%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vámi sdílel(a) „%2$s“. Už jste měli dostat e-mail s přístupovými údaji.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s s vámi sdílel(a) „%2$s“. Už jste měli dostat e-mail s přístupovými údaji.",
    "Password to access »%1$s« shared to you by %2$s" : "Heslo pro přístup k „%1$s“ které s vámi sdílí %2$s",
    "Password to access »%s«" : "Heslo pro přístup k „%s“",
    "It is protected with the following password:" : "Je chráněno následujícím heslem:",
    "%1$s via %2$s" : "%1$s prostřednictvm %2$s",
    "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
    "Open »%s«" : "Otevřít „%s“",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vám nasdílel(a) vícero souborů.\nMěli byste už obdržet i další e-mail s odkazem na přístup k nim.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vám nasdílel(a) vícero souborů. Měli byste už mít jiný e-mail s odkazem pro přístup k nim.",
    "Password to access files shared to you by %1$s" : "Heslo pro přístup k souborům, které vám nasdílel(a) %1$s",
    "Password to access files" : "Heslo pro přístup k souborům",
    "%s shared multiple files with \"%s\"." : "%s nasdílel(a) několik souborů uživateli/skupině „%s“.",
    "%s shared multiple files with you." : "%s vám nasdílel(a) vícero souborů.",
    "Boot up" : "Nastartovat",
    "Initialisation Nextcloud" : "Inicializace Nextcloud",
    "Initialisation Circles App" : "Inicializace aplikace Okruhy",
    "Fresh installation status" : "Stav čisté instalace",
    "Building Local Database" : "Vytváří se místní databáze",
    "Testing Basic Circle Creation" : "Zkouší se vytvoření základního okruhu",
    "Adding local users and moderators" : "Přidávají se místní uživatelé a moderátoři",
    "Circle not found" : "Okruh nenalezen",
    "Circle not found " : "Okruh nenalezen",
    "A circle with that name exists" : "Okruh s tímto názvem už existuje",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Aplikaci Okruhy nelze použít dokud správce nepovolí vytváření alespoň jednoho typu okruhů",
    "This member does not exist" : "Tento člen neexistuje",
    "This account is already a member of the circle" : "Tento účet už je členem okruhu",
    "Federated link not found" : "Federovaný odkaz nebyl nalezen",
    "This feature is not available for personal circles" : "Tato funkce není pro osobní okruhy dostupná",
    "The circle is not federated" : "Okruh není federovaný",
    "You cannot join this circle" : "K tomuto okruhu se nemůžete připojit",
    "This member is not a moderator" : "Tento člen není moderátorem",
    "Insufficient privileges" : "Nedostatečná oprávnění",
    "This member is the owner of the circle" : "Tento člen je vlastníkem tohoto okruhu",
    "Level cannot be changed for this type of member" : "Úroveň nelze pro tento typ člena změnit",
    "You are already a member of this circle" : "Už jste členem tohoto okruhu",
    "You have been blocked from this circle" : "Tento okruh vás zablokoval",
    "The account is already a member of this circle" : "Účet už je členem tohoto okruhu",
    "The account has already been invited into this circle" : "Účet už byl pozván do tohoto okruhu",
    "%s (Circle owned by %s)" : "%s (Okruh vlastněn uživatelem %s)",
    "You are now a member of the Circle \"%2$s\"" : "Nyní jste členy okruhu „%2$s“",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s vás pozval(a) do okruhu „%2$s“",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s poslal(a) žádost o to, stát se členem okruhu „%2$s“",
    "Accept" : "Přijmout",
    "Refuse" : "Odmítnout",
    "Leave the circle" : "Opustit okruh",
    "%s" : "%s",
    "Personal Circle" : "Osobní okruh",
    "%s owned by %s" : "%s vlastněné uživ. %s",
    "You need a specify a type of circle" : "Vyberte typ okruhu",
    "This member is not the owner of the circle" : "Tento člen není vlastníkem tohoto okruhu",
    "This member is not an admin of the circle" : "Tento člen není správcem okruhu",
    "Group contains too many members" : "Skupina obsahuje příliš mnoho členů",
    "This group does not exist" : "Tato skupina neexistuje",
    "This group is already linked to the circle" : "Tato skupina je s okruhem už propojena",
    "You cannot edit level in a personal circle" : "Úroveň osobního okruhu nelze upravit",
    "Group cannot be set as owner of a circle" : "Skupina nemůže být nastavena jako vlastník okruhu",
    "now" : "nyní",
    "This account does not exist" : "Tento účet neexistuje",
    "Email format is not valid" : "Neplatný formát e-mailu",
    "This contact is not available" : "Tento kontakt není k dispozici",
    "You have no permission to create a new circle" : "Nemáte oprávnění pro vytváření nových okruhů",
    "%s shared a file with \"%s\"." : "%s nasdílel(a) soubor uživateli „%s“",
    "%s shared a file with you." : "%s vám nasdílel(a) soubor.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vám nasdílel(a) nějaký obsah.\nUž by vám měl přijít zvlášť e-mail s odkazem pro přístup k němu.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s vám nasdílel(a) nějaký obsah.\nUž by vám měl přijít zvlášť e-mail s odkazem pro přístup k němu.",
    "Password to access content shared with you by %1$s" : "Heslo pro přístup k obsahu, který vám nasdílel(a) %1$s",
    "Password to access content" : "Heslo pro přístup k obsahu",
    "This item is already shared with this circle" : "Tato položka už je v tomto okruhu sdílená",
    "Could not find share" : "Sdílení se nedaří nalézt",
    "Bring cloud-users closer together." : "Sblížit uživatele cloudu.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Okruhy lidem umožňují vytvářet si své vlastní skupiny lidí/kolegů/přátel.\nTyto skupiny uživatelů (neboli „okruhy“) je možné používat v libovolné aplikaci pro účely sdílení.",
    "No files in here" : "Nejsou zde žádné soubory",
    "No entries found in this folder" : "V této složce nebyly nalezeny žádné položky",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Změněno",
    "Nextcloud User" : "Uživatel v Nextcloud",
    "This user is already a member of the circle" : "Tento uživatel už je členem tohoto okruhu",
    "The user is already a member of this circle" : "Uživatel už je členem tohoto okruhu",
    "The user has already been invited into this circle" : "Uživatel už byl do tohoto okruhu pozván",
    "This user does not exist" : "Tento uživatel neexistuje",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Okruhy vašim uživatelům umožňují vytvářet si své vlastní skupiny uživatelů/kolegů/přátel.\nTyto skupiny uživatelů (neboli „okruhy“) je možné používat v libovolné aplikaci pro účely sdílení."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-31.0.10rc1.tar.bz2: nextcloud/apps/circles/l10n/cs.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Týmy",
    "You created the team {circle}" : "Vytvořili jste tým {circle}",
    "{author} created the team {circle}" : "{author} vytvořil(a) tým {circle}",
    "You deleted {circle}" : "Smazali jste okruh {circle}",
    "{author} deleted {circle}" : "{author} smazal(a) {circle}",
    "You made {member} join {circle}" : "Přidali jste {member} do {circle}",
    "{author} made {member} join {circle}" : "{author} přidal(a) {member} do {circle}",
    "You added team {member} as member to {circle}" : "Přidali jste tým {member} jako člena do {circle}",
    "{author} added team {member} as member to {circle}" : "{author} přidal(a) tým {member} jako člena do {circle}",
    "You made {member} leave {circle}" : "Docílili jste že {member} opustil {circle}",
    "{author} made {member} leave {circle}" : "{author} docílil(a) že {member} opustil(a) {circle}",
    "You removed {member} from {circle}" : "Odebrali jste {member} z {circle}",
    "{author} removed {member} from {circle}" : "{author} odebral(a) {member} z {circle}",
    "You joined {circle}" : "Připojili jste se k {circle}",
    "{member} joined {circle}" : "{member} se připojil(a) k {circle}",
    "You accepted the invitation to join {circle}" : "Přijali jste pozvánku k připojení  se do {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} přijal(a) pozvánku připojit se k  {circle}",
    "You added {member} as member to {circle}" : "Přidali jste {member} jako člena {circle}",
    "You have been added as member to {circle} by {author}" : " {author} vás přidal(a) jako člena {circle} ",
    "{member} has been added as member to {circle} by {author}" : "{author} přidal(a) {member} jako člena do {circle}",
    "You added {external} to {circle}" : "Přidali jste {external} do {circle}",
    "{external} has been added to {circle} by {author}" : "{author} přidal(a) {external} do {circle} ",
    "You accepted {member}'s request to join {circle}" : "Přijali jste požadavek od {member} na připojení se do {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Váš požadavek na přidání se k {circle} byl {author} přijat",
    "{member}'s request to join {circle} has been accepted by {author}" : "Požadavek {member} na přidání do {circle} byl {author} přijat",
    "You left {circle}" : "Odešli jste z {circle}",
    "{member} left {circle}" : "{member} opustil(a) {circle}",
    "You declined the invitation to join {circle}" : "Odmítli jste pozvání k přidání se k {circle}",
    "{member} declined an invitation to join {circle}" : "{member} odmítl pozvání k přidání se {circle}",
    "You cancelled your request to join {circle}" : "Vzali jste zpět svou žádost na připojení se k {circle}",
    "{member} cancelled a request to join {circle}" : "{member} vzal(a) zpět svou žádost o přidání do {circle}",
    "You have been removed from {circle} by {author}" : "{author} vás odebral(a) z {circle}  ",
    "{member} has been removed from {circle} by {author}" : "{author} odebral(a) {member} z {circle}",
    "You removed {external} from {circle}" : "Odebrali jste {external} z {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odebral(a) {external} z {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Zrušili jste pozvánku pro {member} připojení se k {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} zrušil(a) pozvání k připojení se do {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} zrušil(a) pozvánku pro {member} pro připojení se k {circle}",
    "You dismissed {member}'s request to join {circle}" : "Schovali jste požadavek od {member} ohledně připojení se k {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} zahodil váš požadavek na přidání se do {circle} ",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} zahodil požadavek od {member} na zapojení se do {circle} ",
    "You invited {member} to join {circle}" : "Pozvali jste {member} aby se připojil(a) k {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vás pozval(a) do {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pozval(a) {member} do {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Změnili jste úroveň {member} v {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} změnil(a) vaši úroveň v {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} změnil(a) úroveň {member} v {circle} na %1$s",
    "You sent a request to join {circle}" : "Poslali jste požadavek na připojení k {circle}",
    "{member} sent a request to join {circle}" : "{member} poslal(a) požadavek na připojení se k {circle}",
    "You are the new owner of {circle}" : "Stali jste se novým vlastníkem {circle}",
    "{member} is the new owner of {circle}" : "{member} je novým vlastníkem {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Při událostech odehrávajících se v <strong>týmu</strong>, kterého jste členy",
    "Any important event in a <strong>team</strong> you are moderating" : "Důležité události v <strong>týmu</strong>, který moderujete",
    "On global events happening in any <strong>team</strong>" : "Při globálních událostech odehrávajících se v jakémkoli <strong>týmu</strong>",
    "Single" : "Jediné",
    "Personal" : "Osobní",
    "System" : "Systém",
    "Visible" : "Viditelný",
    "Open" : "Otevřít",
    "Invite" : "Pozvat",
    "Join request" : "Žádost o přidání se",
    "Friends" : "Přátelé",
    "Password protected" : "Chráněno heslem",
    "No Owner" : "Bez vlastníka",
    "Hidden" : "Skrytý",
    "Backend" : "Podpůrná vrstva",
    "Local" : "Místní",
    "Root" : "Kořen",
    "Team invite" : "Pozvání týmu",
    "Federated" : "Propojené",
    "Mount point" : "Přípojný bod",
    "Nextcloud Account" : "Nextcloud účet",
    "Nextcloud Group" : "Skupina v Nextcloud",
    "Email address" : "E-mailová adresa",
    "Contact" : "Kontakt",
    "Team" : "Tým",
    "Nextcloud App" : "Nextcloud aplikace",
    "Teams App" : "Aplikace Týmy",
    "Admin Command Line" : "Příkazový řádek správce",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Správce",
    "Owner" : "Vlastník",
    "%s shared »%s« with you." : "%s vám nasdílel(a) „%s“.",
    "%s shared »%s« with \"%s\"." : "%s nasdílel(a) „%s“ uživateli „%s“.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vámi sdílel(a) „%2$s“. Už jste měli dostat e-mail s přístupovými údaji.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s s vámi sdílel(a) „%2$s“. Už jste měli dostat e-mail s přístupovými údaji.",
    "Password to access »%1$s« shared to you by %2$s" : "Heslo pro přístup k „%1$s“ které s vámi sdílí %2$s",
    "Password to access »%s«" : "Heslo pro přístup k „%s“",
    "It is protected with the following password:" : "Je chráněno následujícím heslem:",
    "%1$s via %2$s" : "%1$s prostřednictvm %2$s",
    "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
    "Open »%s«" : "Otevřít „%s“",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vám nasdílel(a) vícero souborů.\nMěli byste už obdržet i další e-mail s odkazem na přístup k nim.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vám nasdílel(a) vícero souborů. Měli byste už mít jiný e-mail s odkazem pro přístup k nim.",
    "Password to access files shared to you by %1$s" : "Heslo pro přístup k souborům, které vám nasdílel(a) %1$s",
    "Password to access files" : "Heslo pro přístup k souborům",
    "%s shared multiple files with \"%s\"." : "%s nasdílel(a) několik souborů uživateli/skupině „%s“.",
    "%s shared multiple files with you." : "%s vám nasdílel(a) vícero souborů.",
    "Boot up" : "Nastartovat",
    "Nextcloud Initialization" : "Inicializace Nextcloud",
    "Circles App Initialization" : "Inicializace aplikace okruhy",
    "Fresh installation status" : "Stav čisté instalace",
    "Building Local Database" : "Vytváří se místní databáze",
    "Testing Basic Circle Creation" : "Zkouší se vytvoření základního okruhu",
    "Adding local users and moderators" : "Přidávají se místní uživatelé a moderátoři",
    "Show all teams" : "Zobrazit veškeré týmy",
    "Create a new team" : "Vytvořit nový tým",
    "Files" : "Soubory",
    "This feature is not available for personal circles" : "Tato funkce není pro osobní okruhy dostupná",
    "The team is not federated" : "Tým není federovaný",
    "You cannot join this team" : "K tomuto týmu se nemůžete připojit",
    "This member is not a moderator" : "Tento člen není moderátorem",
    "Insufficient privileges" : "Nedostatečná oprávnění",
    "This member does not exist" : "Tento člen neexistuje",
    "This member is the owner of the team" : "Tento člen je vlastníkem tohoto týmu",
    "Level cannot be changed for this type of member" : "Úroveň nelze pro tento typ člena změnit",
    "You are already a member of this circle" : "Už jste členem tohoto okruhu",
    "You have been blocked from this circle" : "Tento okruh vás zablokoval",
    "The account is already a member of this circle" : "Účet už je členem tohoto okruhu",
    "The account has already been invited into this circle" : "Účet už byl pozván do tohoto okruhu",
    "%s (Team owned by %s)" : "%s (Tým vlastněn uživatelem %s)",
    "You are now a member of the Team \"%2$s\"" : "Nyní jste členy týmu „%2$s“",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s vás pozval(a) do týmu „%2$s“",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s poslal(a) žádost o to, stát se členem týmu „%2$s“",
    "Accept" : "Přijmout",
    "Refuse" : "Odmítnout",
    "Leave the team" : "Opustit tým",
    "%s" : "%s",
    "Personal team" : "Osobní tým",
    "%s owned by %s" : "%s vlastněné uživ. %s",
    "You have no permission to create a new team" : "Nemáte oprávnění pro vytváření nových týmů",
    "%s shared a file with \"%s\"." : "%s nasdílel(a) soubor uživateli „%s“",
    "%s shared a file with you." : "%s vám nasdílel(a) soubor.",
    "%1$s shared %2$s with %3$s" : "%1$s nasdílel/a %2$s uživateli %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s nasdílel/a %2$s uživateli „%3$s“",
    "Open %s" : "Otevřít %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vám nasdílel(a) nějaký obsah.\nUž by vám měl přijít zvlášť e-mail s odkazem pro přístup k němu.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s vám nasdílel(a) nějaký obsah.\nUž by vám měl přijít zvlášť e-mail s odkazem pro přístup k němu.",
    "Password to access content shared with you by %1$s" : "Heslo pro přístup k obsahu, který vám nasdílel(a) %1$s",
    "Password to access content" : "Heslo pro přístup k obsahu",
    "This item is already shared with this team" : "Tato položka už je v tomto týmu sdílená",
    "Bring cloud-users closer together." : "Sblížit uživatele cloudu.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Týmy lidem umožňují vytvářet si své vlastní skupiny lidí/kolegů/přátel.\nTyto skupiny uživatelů (neboli „okruhy“) je možné používat v libovolné aplikaci pro účely sdílení.",
    "Failed to load teams" : "Týmy se nepodařilo načíst",
    "Try again" : "Zkusit znovu",
    "No teams found" : "Nenalezeny žádné týmy",
    "Join or create teams to see them here." : "Aby se zde zobrazily, připojte se k týmům (nebo nějaké vytvořte).",
    "Create your first team" : "Vytvořte svůj první tým",
    "Loading…" : "Načítání…",
    "More teams" : "Další týmy",
    "No files in here" : "Nejsou zde žádné soubory",
    "No entries found in this folder" : "V této složce nebyly nalezeny žádné položky",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Změněno",
    "Shared to Circles" : "Sdíleno do okruhů",
    "Circle" : "Okruh"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
